@@ -12,3 +12,9 @@ class TestAVKitTypes(TestCase):
         self.assertEqual(AVKit.AVVideoFrameAnalysisTypeSubject, 1 << 2)
         self.assertEqual(AVKit.AVVideoFrameAnalysisTypeVisualSearch, 1 << 3)
         self.assertEqual(AVKit.AVVideoFrameAnalysisTypeMachineReadableCode, 1 << 4)
+
+        self.assertIsEnumType(AVKit.AVDisplayDynamicRange)
+        self.assertEqual(AVKit.AVDisplayDynamicRangeAutomatic, 0)
+        self.assertEqual(AVKit.AVDisplayDynamicRangeStandard, 1)
+        self.assertEqual(AVKit.AVDisplayDynamicRangeConstrainedHigh, 2)
+        self.assertEqual(AVKit.AVDisplayDynamicRangeHigh, 3)
